# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MongoMigrationStatusEnum(str, Enum):
    """
    * `pending` - Pending * `in_progress` - In Progress * `completed` - Completed * `failed` - Failed * `canceled` - Canceled
    """

    """
    allowed enum values
    """
    PENDING = 'pending'
    IN_PROGRESS = 'in_progress'
    COMPLETED = 'completed'
    FAILED = 'failed'
    CANCELED = 'canceled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MongoMigrationStatusEnum from a JSON string"""
        return cls(json.loads(json_str))


