# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_tags_api import ApplicationsTablesTagsApi


class TestApplicationsTablesTagsApi(unittest.TestCase):
    """ApplicationsTablesTagsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesTagsApi()

    def tearDown(self) -> None:
        pass

    def test_apps_table_tags_retrieve(self) -> None:
        """Test case for apps_table_tags_retrieve

        Get Table Tags
        """
        pass

    def test_apps_table_tags_tag_destroy(self) -> None:
        """Test case for apps_table_tags_tag_destroy

        Get Tag by ID
        """
        pass

    def test_apps_table_tags_tag_retrieve(self) -> None:
        """Test case for apps_table_tags_tag_retrieve

        Get Tag by ID
        """
        pass

    def test_apps_table_tags_tag_update(self) -> None:
        """Test case for apps_table_tags_tag_update

        Get Tag by ID
        """
        pass


if __name__ == '__main__':
    unittest.main()
