# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.csv_export_request import CsvExportRequest

class TestCsvExportRequest(unittest.TestCase):
    """CsvExportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CsvExportRequest:
        """Test CsvExportRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CsvExportRequest`
        """
        model = CsvExportRequest()
        if include_optional:
            return CsvExportRequest(
                collection_name = '0',
                file = bytes(b'blah'),
                task_id = '',
                application = 56,
                user = 56
            )
        else:
            return CsvExportRequest(
                collection_name = '0',
                application = 56,
                user = 56,
        )
        """

    def testCsvExportRequest(self):
        """Test CsvExportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
