# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_csv_import_api import ApplicationsTablesCSVImportApi


class TestApplicationsTablesCSVImportApi(unittest.TestCase):
    """ApplicationsTablesCSVImportApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesCSVImportApi()

    def tearDown(self) -> None:
        pass

    def test_apps_csv_imports_create(self) -> None:
        """Test case for apps_csv_imports_create

        """
        pass

    def test_apps_csv_imports_destroy(self) -> None:
        """Test case for apps_csv_imports_destroy

        """
        pass

    def test_apps_csv_imports_list(self) -> None:
        """Test case for apps_csv_imports_list

        """
        pass

    def test_apps_csv_imports_partial_update(self) -> None:
        """Test case for apps_csv_imports_partial_update

        """
        pass

    def test_apps_csv_imports_retrieve(self) -> None:
        """Test case for apps_csv_imports_retrieve

        """
        pass

    def test_apps_csv_imports_update(self) -> None:
        """Test case for apps_csv_imports_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
