# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_api import ApplicationsTablesApi


class TestApplicationsTablesApi(unittest.TestCase):
    """ApplicationsTablesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesApi()

    def tearDown(self) -> None:
        pass

    def test_apps_edit_table_update(self) -> None:
        """Test case for apps_edit_table_update

        Edit Application Table
        """
        pass

    def test_apps_get_app_retrieve(self) -> None:
        """Test case for apps_get_app_retrieve

        """
        pass

    def test_apps_new_table_create(self) -> None:
        """Test case for apps_new_table_create

        Create Application Table
        """
        pass

    def test_apps_table_configuration_update(self) -> None:
        """Test case for apps_table_configuration_update

        Get Application Table Configuration
        """
        pass

    def test_apps_table_delete_rows_destroy(self) -> None:
        """Test case for apps_table_delete_rows_destroy

        Delete Rows from Application Table
        """
        pass

    def test_apps_table_new_row_create(self) -> None:
        """Test case for apps_table_new_row_create

        Add Row to Application Table
        """
        pass

    def test_apps_table_rows_retrieve(self) -> None:
        """Test case for apps_table_rows_retrieve

        Get Row from Application Table
        """
        pass

    def test_apps_table_rows_update(self) -> None:
        """Test case for apps_table_rows_update

        Get Row from Application Table
        """
        pass

    def test_apps_tables_retrieve(self) -> None:
        """Test case for apps_tables_retrieve

        Get Application Tables
        """
        pass

    def test_apps_user_tables_retrieve(self) -> None:
        """Test case for apps_user_tables_retrieve

        Get User Application Tables
        """
        pass


if __name__ == '__main__':
    unittest.main()
