# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.get_list200_response_inner import GetList200ResponseInner

class TestGetList200ResponseInner(unittest.TestCase):
    """GetList200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetList200ResponseInner:
        """Test GetList200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetList200ResponseInner`
        """
        model = GetList200ResponseInner()
        if include_optional:
            return GetList200ResponseInner(
                id = ''
            )
        else:
            return GetList200ResponseInner(
                id = '',
        )
        """

    def testGetList200ResponseInner(self):
        """Test GetList200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
