# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.integration_settings import IntegrationSettings

class TestIntegrationSettings(unittest.TestCase):
    """IntegrationSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationSettings:
        """Test IntegrationSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationSettings`
        """
        model = IntegrationSettings()
        if include_optional:
            return IntegrationSettings(
                integration_id = '',
                type = robotnikai.models.integration_type.IntegrationType(
                    code = '', 
                    name = '', 
                    icon = '', ),
                connected_accounts = None,
                account_fields = None,
                dependencies = None,
                scope = '',
                accept_header = '',
                api_auth_header_name = '',
                api_auth_header_key = '',
                api_base_url = ''
            )
        else:
            return IntegrationSettings(
                integration_id = '',
        )
        """

    def testIntegrationSettings(self):
        """Test IntegrationSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
