# coding: utf-8

"""
    CUA API

    Documentation of API endpoints of CUA

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.mongo_migration import MongoMigration

class TestMongoMigration(unittest.TestCase):
    """MongoMigration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MongoMigration:
        """Test MongoMigration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MongoMigration`
        """
        model = MongoMigration()
        if include_optional:
            return MongoMigration(
                id = 56,
                status = 'pending',
                collection_name = '',
                migration_name = '',
                old_schema = None,
                new_schema = None,
                renamed = None,
                added = None,
                removed = None,
                changed = None,
                task_id = '',
                type_conversion_policy = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                application = 56
            )
        else:
            return MongoMigration(
                id = 56,
                collection_name = '',
                migration_name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                application = 56,
        )
        """

    def testMongoMigration(self):
        """Test MongoMigration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
